@@ -7,14 +7,16 @@ from .exceptions import (
 from .util import (
     from_iso_date, to_iso_date,
     response_json, response_boolean,
-    build_resource_attributes, build_resource_relationship,
+    build_request_attributes, build_request_relationship,
+    build_request_include,
 )
 from .resource import Base, Resource, ResourceMeta
 from .relations import RelationType, to_many, to_one
+from .live_session import LiveSession
 from .session import Session
 from .metadata import Metadata, metadata
 from .user import User
-from .timeseries import Timeseries, timeseries
+from .timeseries import Timeseries, DataPoint, AggregateValue, timeseries
 from .sensor import Sensor
 from .label import Label
 from .element import Element
@@ -28,17 +30,18 @@ from .__about__ import (
 
 __all__ = (
     from_iso_date, to_iso_date, response_json, response_boolean,
-    build_resource_attributes, build_resource_relationship,
+    build_request_attributes, build_request_relationship,
+    build_request_include,
     Error,
     ServerError,
     ClientError,
     NotFoundError,
     Base, Resource, ResourceMeta,
     RelationType, to_one, to_many,
-    Session,
+    Session, LiveSession,
     Organization,
     User,
-    Timeseries, timeseries,
+    Timeseries, DataPoint, timeseries, AggregateValue,
     Sensor,
     Metadata, metadata,
     Element,
